@@ -2,10 +2,15 @@ import pytest
 
 from gitlabform.gitlab.core import UnexpectedResponseException
 from gitlabform.gitlabform import GitLabForm
-from gitlabform.gitlabform.test import create_group, create_project_in_group, get_gitlab, GROUP_NAME
+from gitlabform.gitlabform.test import (
+    create_group,
+    create_project_in_group,
+    get_gitlab,
+    GROUP_NAME,
+)
 
-PROJECT_NAME = 'secret_variables_project'
-GROUP_AND_PROJECT_NAME = GROUP_NAME + '/' + PROJECT_NAME
+PROJECT_NAME = "secret_variables_project"
+GROUP_AND_PROJECT_NAME = GROUP_NAME + "/" + PROJECT_NAME
 
 
 @pytest.fixture(scope="function")
@@ -22,12 +27,15 @@ def gitlab(request):
     return gl  # provide fixture value
 
 
-config_builds_not_enabled = """
+config_builds_not_enabled = (
+    """
 gitlab:
   api_version: 4
 
 project_settings:
-  """ + GROUP_AND_PROJECT_NAME + """:
+  """
+    + GROUP_AND_PROJECT_NAME
+    + """:
     project_settings:
       builds_access_level: disabled
     secret_variables:
@@ -35,13 +43,17 @@ project_settings:
         key: FOO
         value: 123
 """
+)
 
-config_single_secret_variable = """
+config_single_secret_variable = (
+    """
 gitlab:
   api_version: 4
 
 project_settings:
-  """ + GROUP_AND_PROJECT_NAME + """:
+  """
+    + GROUP_AND_PROJECT_NAME
+    + """:
     project_settings:
       builds_access_level: enabled
     secret_variables:
@@ -49,13 +61,17 @@ project_settings:
         key: FOO
         value: 123
 """
+)
 
-config_delete_secret_variable = """
+config_delete_secret_variable = (
+    """
 gitlab:
   api_version: 4
 
 project_settings:
-  """ + GROUP_AND_PROJECT_NAME + """:
+  """
+    + GROUP_AND_PROJECT_NAME
+    + """:
     project_settings:
       builds_access_level: enabled
     secret_variables:
@@ -64,13 +80,17 @@ project_settings:
         value: 123
         delete: true
 """
+)
 
-config_single_secret_variable2 = """
+config_single_secret_variable2 = (
+    """
 gitlab:
   api_version: 4
 
 project_settings:
-  """ + GROUP_AND_PROJECT_NAME + """:
+  """
+    + GROUP_AND_PROJECT_NAME
+    + """:
     project_settings:
       builds_access_level: enabled
     secret_variables:
@@ -78,13 +98,17 @@ project_settings:
         key: FOO
         value: 123456
 """
+)
 
-config_more_secret_variables = """
+config_more_secret_variables = (
+    """
 gitlab:
   api_version: 4
 
 project_settings:
-  """ + GROUP_AND_PROJECT_NAME + """:
+  """
+    + GROUP_AND_PROJECT_NAME
+    + """:
     project_settings:
       builds_access_level: enabled
     secret_variables:
@@ -95,13 +119,15 @@ project_settings:
         key: BAR
         value: bleble
 """
+)
 
 
 class TestSecretVariables:
-
     def test__builds_disabled(self, gitlab):
-        gf = GitLabForm(config_string=config_builds_not_enabled,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_builds_not_enabled,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         with pytest.raises(UnexpectedResponseException):
@@ -109,52 +135,64 @@ class TestSecretVariables:
             gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
 
     def test__single_secret_variable(self, gitlab):
-        gf = GitLabForm(config_string=config_single_secret_variable,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_single_secret_variable,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
         assert len(secret_variables) == 1
 
     def test__delete_secret_variable(self, gitlab):
-        gf = GitLabForm(config_string=config_single_secret_variable,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_single_secret_variable,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
         assert len(secret_variables) == 1
-        assert secret_variables[0]['value'] == '123'
+        assert secret_variables[0]["value"] == "123"
 
-        gf = GitLabForm(config_string=config_delete_secret_variable,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_delete_secret_variable,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
         assert len(secret_variables) == 0
 
     def test__reset_single_secret_variable(self, gitlab):
-        gf = GitLabForm(config_string=config_single_secret_variable,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_single_secret_variable,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
         assert len(secret_variables) == 1
-        assert secret_variables[0]['value'] == '123'
+        assert secret_variables[0]["value"] == "123"
 
-        gf = GitLabForm(config_string=config_single_secret_variable2,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_single_secret_variable2,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
         assert len(secret_variables) == 1
-        assert secret_variables[0]['value'] == '123456'
+        assert secret_variables[0]["value"] == "123456"
 
     def test__more_secret_variables(self, gitlab):
-        gf = GitLabForm(config_string=config_more_secret_variables,
-                        project_or_group=GROUP_AND_PROJECT_NAME)
+        gf = GitLabForm(
+            config_string=config_more_secret_variables,
+            project_or_group=GROUP_AND_PROJECT_NAME,
+        )
         gf.main()
 
         secret_variables = gitlab.get_secret_variables(GROUP_AND_PROJECT_NAME)
-        secret_variables_keys = set([secret['key'] for secret in secret_variables])
+        secret_variables_keys = set([secret["key"] for secret in secret_variables])
         assert len(secret_variables) == 2
-        assert secret_variables_keys == {'FOO', 'BAR'}
+        assert secret_variables_keys == {"FOO", "BAR"}
